@@ -47,38 +47,50 @@ class Project:
     Projects are containers for logs, traces, and other data in Galileo. All logs are stored
     within a project, and users can create and manage projects to organize their LLM usage data.
 
-    Attributes:
-        created_at (datetime.datetime): The timestamp when the project was created.
-        created_by (str): The identifier of the user who created the project.
-        id (str): The unique identifier of the project.
-        updated_at (datetime.datetime): The timestamp when the project was last updated.
-        bookmark (Union[Unset, bool]): Whether the project is bookmarked. Defaults to False.
-        name (Union[None, Unset, str]): The name of the project.
-        permissions (Union[Unset, list["Permission"]]): The permissions associated with the project.
-        type (Union[None, ProjectType, Unset]): The type of the project, typically GEN_AI.
+    Attributes
+    ----------
+    created_at: datetime.datetime
+        The timestamp when the project was created.
+    created_by: str
+        The identifier of the user who created the project.
+    id: str
+        The unique identifier of the project.
+    updated_at: datetime.datetime
+        The timestamp when the project was last updated.
+    bookmark: Union[Unset, bool]
+        Whether the project is bookmarked. Defaults to False.
+    name: Union[None, Unset, str]
+        The name of the project.
+    permissions: Union[Unset, list["Permission"]])
+        The permissions associated with the project.
+    type: Union[None, ProjectType, Unset]
+        The type of the project, typically GEN_AI.
 
-    Examples:
-         from galileo.projects import get_project, create_project, list_projects, delete_project
+    Examples
+    --------
+    ```python
+    from galileo.projects import get_project, create_project, list_projects, delete_project
 
-         # Create a new project
-         project = create_project(name="My AI Project")
+    # Create a new project
+    project = create_project(name="My AI Project")
 
-         # Get a project by name
-         project = get_project(name="My AI Project")
+    # Get a project by name
+    project = get_project(name="My AI Project")
 
-         # Get a project by ID
-         project = get_project(id="project-id-123")
+    # Get a project by ID
+    project = get_project(id="project-id-123")
 
-         # List all projects
-         projects = list_projects()
-         for project in projects:
-             print(f"Project: {project.name} (ID: {project.id})")
+    # List all projects
+    projects = list_projects()
+    for project in projects:
+        print(f"Project: {project.name} (ID: {project.id})")
 
-         # Delete a project by name
-         delete_project(name="My AI Project")
+    # Delete a project by name
+    delete_project(name="My AI Project")
 
-         # Delete a project by ID
-         delete_project(id="project-id-123")
+    # Delete a project by ID
+    delete_project(id="project-id-123")
+    ```
     """
 
     created_at: datetime.datetime
@@ -94,10 +106,11 @@ class Project:
         """
         Initialize a Project instance.
 
-        Args:
-            project (Union[None, ProjectDBThin, ProjectDB, ProjectCreateResponse], optional):
-                The project data to initialize from. If None, creates an empty project instance.
-                Defaults to None.
+        Parameters
+        ----------
+        project (Union[None, ProjectDBThin, ProjectDB, ProjectCreateResponse], optional):
+            The project data to initialize from. If None, creates an empty project instance.
+            Defaults to None.
         """
         if project is None:
             return
@@ -156,6 +169,7 @@ class Projects(DecorateAllMethods):
             The id of the project.
         name : str
             The name of the project.
+
         Returns
         -------
         Project
@@ -186,6 +200,7 @@ class Projects(DecorateAllMethods):
             The id of the project.
         name : str
             The name of the project.
+
         Returns
         -------
         Project
