@@ -41,16 +41,17 @@ def _build_response(*, client: ApiClient, response: httpx.Response) -> Response[
 
 
 def sync_detailed(*, client: ApiClient) -> Response[list[str]]:
-    """List Tags
+    """List Tags.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[list[str]]
     """
-
     kwargs = _get_kwargs()
 
     response = client.request(**kwargs)
@@ -59,30 +60,32 @@ def sync_detailed(*, client: ApiClient) -> Response[list[str]]:
 
 
 def sync(*, client: ApiClient) -> Optional[list[str]]:
-    """List Tags
+    """List Tags.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         list[str]
     """
-
     return sync_detailed(client=client).parsed
 
 
 async def asyncio_detailed(*, client: ApiClient) -> Response[list[str]]:
-    """List Tags
+    """List Tags.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[list[str]]
     """
-
     kwargs = _get_kwargs()
 
     response = await client.arequest(**kwargs)
@@ -91,14 +94,15 @@ async def asyncio_detailed(*, client: ApiClient) -> Response[list[str]]:
 
 
 async def asyncio(*, client: ApiClient) -> Optional[list[str]]:
-    """List Tags
+    """List Tags.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         list[str]
     """
-
     return (await asyncio_detailed(client=client)).parsed
