@@ -49,20 +49,21 @@ def _build_response(*, client: ApiClient, response: httpx.Response) -> Response[
 
 
 def sync_detailed(project_id: str, dataset_id: str, *, client: ApiClient) -> Response[Union[Any, HTTPValidationError]]:
-    """Download Prompt Dataset
+    """Download Prompt Dataset.
 
     Args:
         project_id (str):
         dataset_id (str):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[Any, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, dataset_id=dataset_id)
 
     response = client.request(**kwargs)
@@ -71,40 +72,42 @@ def sync_detailed(project_id: str, dataset_id: str, *, client: ApiClient) -> Res
 
 
 def sync(project_id: str, dataset_id: str, *, client: ApiClient) -> Optional[Union[Any, HTTPValidationError]]:
-    """Download Prompt Dataset
+    """Download Prompt Dataset.
 
     Args:
         project_id (str):
         dataset_id (str):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[Any, HTTPValidationError]
     """
-
     return sync_detailed(project_id=project_id, dataset_id=dataset_id, client=client).parsed
 
 
 async def asyncio_detailed(
     project_id: str, dataset_id: str, *, client: ApiClient
 ) -> Response[Union[Any, HTTPValidationError]]:
-    """Download Prompt Dataset
+    """Download Prompt Dataset.
 
     Args:
         project_id (str):
         dataset_id (str):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[Any, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, dataset_id=dataset_id)
 
     response = await client.arequest(**kwargs)
@@ -113,18 +116,19 @@ async def asyncio_detailed(
 
 
 async def asyncio(project_id: str, dataset_id: str, *, client: ApiClient) -> Optional[Union[Any, HTTPValidationError]]:
-    """Download Prompt Dataset
+    """Download Prompt Dataset.
 
     Args:
         project_id (str):
         dataset_id (str):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[Any, HTTPValidationError]
     """
-
     return (await asyncio_detailed(project_id=project_id, dataset_id=dataset_id, client=client)).parsed
