@@ -67,21 +67,22 @@ def _build_response(
 def sync_detailed(
     project_id: str, *, client: ApiClient, starting_token: Union[Unset, int] = 0, limit: Union[Unset, int] = 100
 ) -> Response[Union[HTTPValidationError, ListPromptDatasetResponse]]:
-    """List Prompt Datasets
+    """List Prompt Datasets.
 
     Args:
         project_id (str):
         starting_token (Union[Unset, int]):  Default: 0.
         limit (Union[Unset, int]):  Default: 100.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, ListPromptDatasetResponse]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, starting_token=starting_token, limit=limit)
 
     response = client.request(**kwargs)
@@ -92,42 +93,44 @@ def sync_detailed(
 def sync(
     project_id: str, *, client: ApiClient, starting_token: Union[Unset, int] = 0, limit: Union[Unset, int] = 100
 ) -> Optional[Union[HTTPValidationError, ListPromptDatasetResponse]]:
-    """List Prompt Datasets
+    """List Prompt Datasets.
 
     Args:
         project_id (str):
         starting_token (Union[Unset, int]):  Default: 0.
         limit (Union[Unset, int]):  Default: 100.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, ListPromptDatasetResponse]
     """
-
     return sync_detailed(project_id=project_id, client=client, starting_token=starting_token, limit=limit).parsed
 
 
 async def asyncio_detailed(
     project_id: str, *, client: ApiClient, starting_token: Union[Unset, int] = 0, limit: Union[Unset, int] = 100
 ) -> Response[Union[HTTPValidationError, ListPromptDatasetResponse]]:
-    """List Prompt Datasets
+    """List Prompt Datasets.
 
     Args:
         project_id (str):
         starting_token (Union[Unset, int]):  Default: 0.
         limit (Union[Unset, int]):  Default: 100.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, ListPromptDatasetResponse]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, starting_token=starting_token, limit=limit)
 
     response = await client.arequest(**kwargs)
@@ -138,21 +141,22 @@ async def asyncio_detailed(
 async def asyncio(
     project_id: str, *, client: ApiClient, starting_token: Union[Unset, int] = 0, limit: Union[Unset, int] = 100
 ) -> Optional[Union[HTTPValidationError, ListPromptDatasetResponse]]:
-    """List Prompt Datasets
+    """List Prompt Datasets.
 
     Args:
         project_id (str):
         starting_token (Union[Unset, int]):  Default: 0.
         limit (Union[Unset, int]):  Default: 100.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, ListPromptDatasetResponse]
     """
-
     return (
         await asyncio_detailed(project_id=project_id, client=client, starting_token=starting_token, limit=limit)
     ).parsed
