@@ -77,7 +77,7 @@ def sync_detailed(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Response[Union[DatasetContent, HTTPValidationError]]:
-    """Query Dataset Content
+    """Query Dataset Content.
 
     Args:
         dataset_id (str):
@@ -85,14 +85,15 @@ def sync_detailed(
         limit (Union[Unset, int]):  Default: 100.
         body (QueryDatasetParams):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[DatasetContent, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(dataset_id=dataset_id, body=body, starting_token=starting_token, limit=limit)
 
     response = client.request(**kwargs)
@@ -108,7 +109,7 @@ def sync(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Optional[Union[DatasetContent, HTTPValidationError]]:
-    """Query Dataset Content
+    """Query Dataset Content.
 
     Args:
         dataset_id (str):
@@ -116,14 +117,15 @@ def sync(
         limit (Union[Unset, int]):  Default: 100.
         body (QueryDatasetParams):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[DatasetContent, HTTPValidationError]
     """
-
     return sync_detailed(
         dataset_id=dataset_id, client=client, body=body, starting_token=starting_token, limit=limit
     ).parsed
@@ -137,7 +139,7 @@ async def asyncio_detailed(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Response[Union[DatasetContent, HTTPValidationError]]:
-    """Query Dataset Content
+    """Query Dataset Content.
 
     Args:
         dataset_id (str):
@@ -145,14 +147,15 @@ async def asyncio_detailed(
         limit (Union[Unset, int]):  Default: 100.
         body (QueryDatasetParams):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[DatasetContent, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(dataset_id=dataset_id, body=body, starting_token=starting_token, limit=limit)
 
     response = await client.arequest(**kwargs)
@@ -168,7 +171,7 @@ async def asyncio(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Optional[Union[DatasetContent, HTTPValidationError]]:
-    """Query Dataset Content
+    """Query Dataset Content.
 
     Args:
         dataset_id (str):
@@ -176,14 +179,15 @@ async def asyncio(
         limit (Union[Unset, int]):  Default: 100.
         body (QueryDatasetParams):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[DatasetContent, HTTPValidationError]
     """
-
     return (
         await asyncio_detailed(
             dataset_id=dataset_id, client=client, body=body, starting_token=starting_token, limit=limit
