@@ -61,7 +61,7 @@ def _build_response(*, client: ApiClient, response: httpx.Response) -> Response[
 def sync_detailed(
     dataset_id: str, *, client: ApiClient, body: Union["RollbackRequest", "UpsertDatasetContentRequest"]
 ) -> Response[Union[Any, HTTPValidationError]]:
-    """Upsert Dataset Content
+    """Upsert Dataset Content.
 
      Rollback the content of a dataset to a previous version.
 
@@ -69,14 +69,15 @@ def sync_detailed(
         dataset_id (str):
         body (Union['RollbackRequest', 'UpsertDatasetContentRequest']):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[Any, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(dataset_id=dataset_id, body=body)
 
     response = client.request(**kwargs)
@@ -87,7 +88,7 @@ def sync_detailed(
 def sync(
     dataset_id: str, *, client: ApiClient, body: Union["RollbackRequest", "UpsertDatasetContentRequest"]
 ) -> Optional[Union[Any, HTTPValidationError]]:
-    """Upsert Dataset Content
+    """Upsert Dataset Content.
 
      Rollback the content of a dataset to a previous version.
 
@@ -95,21 +96,22 @@ def sync(
         dataset_id (str):
         body (Union['RollbackRequest', 'UpsertDatasetContentRequest']):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[Any, HTTPValidationError]
     """
-
     return sync_detailed(dataset_id=dataset_id, client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     dataset_id: str, *, client: ApiClient, body: Union["RollbackRequest", "UpsertDatasetContentRequest"]
 ) -> Response[Union[Any, HTTPValidationError]]:
-    """Upsert Dataset Content
+    """Upsert Dataset Content.
 
      Rollback the content of a dataset to a previous version.
 
@@ -117,14 +119,15 @@ async def asyncio_detailed(
         dataset_id (str):
         body (Union['RollbackRequest', 'UpsertDatasetContentRequest']):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[Any, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(dataset_id=dataset_id, body=body)
 
     response = await client.arequest(**kwargs)
@@ -135,7 +138,7 @@ async def asyncio_detailed(
 async def asyncio(
     dataset_id: str, *, client: ApiClient, body: Union["RollbackRequest", "UpsertDatasetContentRequest"]
 ) -> Optional[Union[Any, HTTPValidationError]]:
-    """Upsert Dataset Content
+    """Upsert Dataset Content.
 
      Rollback the content of a dataset to a previous version.
 
@@ -143,12 +146,13 @@ async def asyncio(
         dataset_id (str):
         body (Union['RollbackRequest', 'UpsertDatasetContentRequest']):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[Any, HTTPValidationError]
     """
-
     return (await asyncio_detailed(dataset_id=dataset_id, client=client, body=body)).parsed
