@@ -57,19 +57,20 @@ def _build_response(
 def sync_detailed(
     *, client: ApiClient, body: CreateJobRequest
 ) -> Response[Union[CreateJobResponse, HTTPValidationError]]:
-    """Create Job
+    """Create Job.
 
     Args:
         body (CreateJobRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[CreateJobResponse, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(body=body)
 
     response = client.request(**kwargs)
@@ -78,38 +79,40 @@ def sync_detailed(
 
 
 def sync(*, client: ApiClient, body: CreateJobRequest) -> Optional[Union[CreateJobResponse, HTTPValidationError]]:
-    """Create Job
+    """Create Job.
 
     Args:
         body (CreateJobRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[CreateJobResponse, HTTPValidationError]
     """
-
     return sync_detailed(client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     *, client: ApiClient, body: CreateJobRequest
 ) -> Response[Union[CreateJobResponse, HTTPValidationError]]:
-    """Create Job
+    """Create Job.
 
     Args:
         body (CreateJobRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[CreateJobResponse, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(body=body)
 
     response = await client.arequest(**kwargs)
@@ -120,17 +123,18 @@ async def asyncio_detailed(
 async def asyncio(
     *, client: ApiClient, body: CreateJobRequest
 ) -> Optional[Union[CreateJobResponse, HTTPValidationError]]:
-    """Create Job
+    """Create Job.
 
     Args:
         body (CreateJobRequest):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[CreateJobResponse, HTTPValidationError]
     """
-
     return (await asyncio_detailed(client=client, body=body)).parsed
