@@ -71,20 +71,21 @@ def _build_response(
 def sync_detailed(
     template_id: str, *, client: ApiClient, body: list["UserCollaboratorCreate"]
 ) -> Response[Union[HTTPValidationError, list["UserCollaborator"]]]:
-    """Create User Prompt Template Collaborators
+    """Create User Prompt Template Collaborators.
 
     Args:
         template_id (str):
         body (list['UserCollaboratorCreate']):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, list['UserCollaborator']]]
     """
-
     kwargs = _get_kwargs(template_id=template_id, body=body)
 
     response = client.request(**kwargs)
@@ -95,40 +96,42 @@ def sync_detailed(
 def sync(
     template_id: str, *, client: ApiClient, body: list["UserCollaboratorCreate"]
 ) -> Optional[Union[HTTPValidationError, list["UserCollaborator"]]]:
-    """Create User Prompt Template Collaborators
+    """Create User Prompt Template Collaborators.
 
     Args:
         template_id (str):
         body (list['UserCollaboratorCreate']):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, list['UserCollaborator']]
     """
-
     return sync_detailed(template_id=template_id, client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     template_id: str, *, client: ApiClient, body: list["UserCollaboratorCreate"]
 ) -> Response[Union[HTTPValidationError, list["UserCollaborator"]]]:
-    """Create User Prompt Template Collaborators
+    """Create User Prompt Template Collaborators.
 
     Args:
         template_id (str):
         body (list['UserCollaboratorCreate']):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, list['UserCollaborator']]]
     """
-
     kwargs = _get_kwargs(template_id=template_id, body=body)
 
     response = await client.arequest(**kwargs)
@@ -139,18 +142,19 @@ async def asyncio_detailed(
 async def asyncio(
     template_id: str, *, client: ApiClient, body: list["UserCollaboratorCreate"]
 ) -> Optional[Union[HTTPValidationError, list["UserCollaborator"]]]:
-    """Create User Prompt Template Collaborators
+    """Create User Prompt Template Collaborators.
 
     Args:
         template_id (str):
         body (list['UserCollaboratorCreate']):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, list['UserCollaborator']]
     """
-
     return (await asyncio_detailed(template_id=template_id, client=client, body=body)).parsed
