@@ -76,7 +76,7 @@ def sync_detailed(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Response[Union[HTTPValidationError, ListPromptTemplateResponse]]:
-    """Query Templates
+    """Query Templates.
 
      Query prompt templates the user has access to.
 
@@ -99,14 +99,15 @@ def sync_detailed(
         limit (Union[Unset, int]):  Default: 100.
         body (ListPromptTemplateParams):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, ListPromptTemplateResponse]]
     """
-
     kwargs = _get_kwargs(body=body, starting_token=starting_token, limit=limit)
 
     response = client.request(**kwargs)
@@ -121,7 +122,7 @@ def sync(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Optional[Union[HTTPValidationError, ListPromptTemplateResponse]]:
-    """Query Templates
+    """Query Templates.
 
      Query prompt templates the user has access to.
 
@@ -144,14 +145,15 @@ def sync(
         limit (Union[Unset, int]):  Default: 100.
         body (ListPromptTemplateParams):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, ListPromptTemplateResponse]
     """
-
     return sync_detailed(client=client, body=body, starting_token=starting_token, limit=limit).parsed
 
 
@@ -162,7 +164,7 @@ async def asyncio_detailed(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Response[Union[HTTPValidationError, ListPromptTemplateResponse]]:
-    """Query Templates
+    """Query Templates.
 
      Query prompt templates the user has access to.
 
@@ -185,14 +187,15 @@ async def asyncio_detailed(
         limit (Union[Unset, int]):  Default: 100.
         body (ListPromptTemplateParams):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, ListPromptTemplateResponse]]
     """
-
     kwargs = _get_kwargs(body=body, starting_token=starting_token, limit=limit)
 
     response = await client.arequest(**kwargs)
@@ -207,7 +210,7 @@ async def asyncio(
     starting_token: Union[Unset, int] = 0,
     limit: Union[Unset, int] = 100,
 ) -> Optional[Union[HTTPValidationError, ListPromptTemplateResponse]]:
-    """Query Templates
+    """Query Templates.
 
      Query prompt templates the user has access to.
 
@@ -230,12 +233,13 @@ async def asyncio(
         limit (Union[Unset, int]):  Default: 100.
         body (ListPromptTemplateParams):
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, ListPromptTemplateResponse]
     """
-
     return (await asyncio_detailed(client=client, body=body, starting_token=starting_token, limit=limit)).parsed
