@@ -59,21 +59,22 @@ def _build_response(*, client: ApiClient, response: httpx.Response) -> Response[
 def sync_detailed(
     project_id: str, stage_id: str, *, client: ApiClient, pause: Union[Unset, bool] = False
 ) -> Response[Union[HTTPValidationError, StageDB]]:
-    """Pause Stage
+    """Pause Stage.
 
     Args:
         project_id (str):
         stage_id (str):
         pause (Union[Unset, bool]):  Default: False.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, StageDB]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, stage_id=stage_id, pause=pause)
 
     response = client.request(**kwargs)
@@ -84,42 +85,44 @@ def sync_detailed(
 def sync(
     project_id: str, stage_id: str, *, client: ApiClient, pause: Union[Unset, bool] = False
 ) -> Optional[Union[HTTPValidationError, StageDB]]:
-    """Pause Stage
+    """Pause Stage.
 
     Args:
         project_id (str):
         stage_id (str):
         pause (Union[Unset, bool]):  Default: False.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, StageDB]
     """
-
     return sync_detailed(project_id=project_id, stage_id=stage_id, client=client, pause=pause).parsed
 
 
 async def asyncio_detailed(
     project_id: str, stage_id: str, *, client: ApiClient, pause: Union[Unset, bool] = False
 ) -> Response[Union[HTTPValidationError, StageDB]]:
-    """Pause Stage
+    """Pause Stage.
 
     Args:
         project_id (str):
         stage_id (str):
         pause (Union[Unset, bool]):  Default: False.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, StageDB]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, stage_id=stage_id, pause=pause)
 
     response = await client.arequest(**kwargs)
@@ -130,19 +133,20 @@ async def asyncio_detailed(
 async def asyncio(
     project_id: str, stage_id: str, *, client: ApiClient, pause: Union[Unset, bool] = False
 ) -> Optional[Union[HTTPValidationError, StageDB]]:
-    """Pause Stage
+    """Pause Stage.
 
     Args:
         project_id (str):
         stage_id (str):
         pause (Union[Unset, bool]):  Default: False.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, StageDB]
     """
-
     return (await asyncio_detailed(project_id=project_id, stage_id=stage_id, client=client, pause=pause)).parsed
