@@ -62,21 +62,22 @@ def stream_detailed(project_id: str, *, client: ApiClient, body: LogRecordsExpor
 def sync_detailed(
     project_id: str, *, client: ApiClient, body: LogRecordsExportRequest
 ) -> Response[Union[Any, HTTPValidationError]]:
-    """Export Records
+    """Export Records.
 
     Args:
         project_id (str):
         body (LogRecordsExportRequest): Request schema for exporting log records (sessions,
             traces, spans).
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[Any, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, body=body)
 
     response = client.request(**kwargs)
@@ -87,42 +88,44 @@ def sync_detailed(
 def sync(
     project_id: str, *, client: ApiClient, body: LogRecordsExportRequest
 ) -> Optional[Union[Any, HTTPValidationError]]:
-    """Export Records
+    """Export Records.
 
     Args:
         project_id (str):
         body (LogRecordsExportRequest): Request schema for exporting log records (sessions,
             traces, spans).
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[Any, HTTPValidationError]
     """
-
     return sync_detailed(project_id=project_id, client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     project_id: str, *, client: ApiClient, body: LogRecordsExportRequest
 ) -> Response[Union[Any, HTTPValidationError]]:
-    """Export Records
+    """Export Records.
 
     Args:
         project_id (str):
         body (LogRecordsExportRequest): Request schema for exporting log records (sessions,
             traces, spans).
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[Any, HTTPValidationError]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, body=body)
 
     response = await client.arequest(**kwargs)
@@ -133,19 +136,20 @@ async def asyncio_detailed(
 async def asyncio(
     project_id: str, *, client: ApiClient, body: LogRecordsExportRequest
 ) -> Optional[Union[Any, HTTPValidationError]]:
-    """Export Records
+    """Export Records.
 
     Args:
         project_id (str):
         body (LogRecordsExportRequest): Request schema for exporting log records (sessions,
             traces, spans).
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[Any, HTTPValidationError]
     """
-
     return (await asyncio_detailed(project_id=project_id, client=client, body=body)).parsed
