@@ -61,7 +61,7 @@ def _build_response(
 def sync_detailed(
     project_id: str, span_id: str, *, client: ApiClient, body: LogSpanUpdateRequest
 ) -> Response[Union[HTTPValidationError, LogSpanUpdateResponse]]:
-    """Update Span
+    """Update Span.
 
      Update a span with the given ID.
 
@@ -70,14 +70,15 @@ def sync_detailed(
         span_id (str):
         body (LogSpanUpdateRequest): Request model for updating a trace.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, LogSpanUpdateResponse]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, span_id=span_id, body=body)
 
     response = client.request(**kwargs)
@@ -88,7 +89,7 @@ def sync_detailed(
 def sync(
     project_id: str, span_id: str, *, client: ApiClient, body: LogSpanUpdateRequest
 ) -> Optional[Union[HTTPValidationError, LogSpanUpdateResponse]]:
-    """Update Span
+    """Update Span.
 
      Update a span with the given ID.
 
@@ -97,21 +98,22 @@ def sync(
         span_id (str):
         body (LogSpanUpdateRequest): Request model for updating a trace.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, LogSpanUpdateResponse]
     """
-
     return sync_detailed(project_id=project_id, span_id=span_id, client=client, body=body).parsed
 
 
 async def asyncio_detailed(
     project_id: str, span_id: str, *, client: ApiClient, body: LogSpanUpdateRequest
 ) -> Response[Union[HTTPValidationError, LogSpanUpdateResponse]]:
-    """Update Span
+    """Update Span.
 
      Update a span with the given ID.
 
@@ -120,14 +122,15 @@ async def asyncio_detailed(
         span_id (str):
         body (LogSpanUpdateRequest): Request model for updating a trace.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Response[Union[HTTPValidationError, LogSpanUpdateResponse]]
     """
-
     kwargs = _get_kwargs(project_id=project_id, span_id=span_id, body=body)
 
     response = await client.arequest(**kwargs)
@@ -138,7 +141,7 @@ async def asyncio_detailed(
 async def asyncio(
     project_id: str, span_id: str, *, client: ApiClient, body: LogSpanUpdateRequest
 ) -> Optional[Union[HTTPValidationError, LogSpanUpdateResponse]]:
-    """Update Span
+    """Update Span.
 
      Update a span with the given ID.
 
@@ -147,12 +150,13 @@ async def asyncio(
         span_id (str):
         body (LogSpanUpdateRequest): Request model for updating a trace.
 
-    Raises:
+    Raises
+    ------
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
-    Returns:
+    Returns
+    -------
         Union[HTTPValidationError, LogSpanUpdateResponse]
     """
-
     return (await asyncio_detailed(project_id=project_id, span_id=span_id, client=client, body=body)).parsed
