@@ -10,6 +10,7 @@ from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
     from ..models.log_records_boolean_filter import LogRecordsBooleanFilter
+    from ..models.log_records_collection_filter import LogRecordsCollectionFilter
     from ..models.log_records_date_filter import LogRecordsDateFilter
     from ..models.log_records_id_filter import LogRecordsIDFilter
     from ..models.log_records_number_filter import LogRecordsNumberFilter
@@ -22,12 +23,13 @@ T = TypeVar("T", bound="LogRecordsMetricsQueryRequest")
 @_attrs_define
 class LogRecordsMetricsQueryRequest:
     """
-    Attributes:
+    Attributes
+    ----------
         end_time (datetime.datetime): Include traces up to this time.
         start_time (datetime.datetime): Include traces from this time onward.
         experiment_id (Union[None, Unset, str]): Experiment id associated with the traces.
-        filters (Union[Unset, list[Union['LogRecordsBooleanFilter', 'LogRecordsDateFilter', 'LogRecordsIDFilter',
-            'LogRecordsNumberFilter', 'LogRecordsTextFilter']]]):
+        filters (Union[Unset, list[Union['LogRecordsBooleanFilter', 'LogRecordsCollectionFilter',
+            'LogRecordsDateFilter', 'LogRecordsIDFilter', 'LogRecordsNumberFilter', 'LogRecordsTextFilter']]]):
         group_by (Union[None, Unset, str]):
         interval (Union[Unset, int]):  Default: 5.
         log_stream_id (Union[None, Unset, str]): Log stream id associated with the traces.
@@ -42,6 +44,7 @@ class LogRecordsMetricsQueryRequest:
         list[
             Union[
                 "LogRecordsBooleanFilter",
+                "LogRecordsCollectionFilter",
                 "LogRecordsDateFilter",
                 "LogRecordsIDFilter",
                 "LogRecordsNumberFilter",
@@ -60,6 +63,7 @@ class LogRecordsMetricsQueryRequest:
         from ..models.log_records_date_filter import LogRecordsDateFilter
         from ..models.log_records_id_filter import LogRecordsIDFilter
         from ..models.log_records_number_filter import LogRecordsNumberFilter
+        from ..models.log_records_text_filter import LogRecordsTextFilter
 
         end_time = self.end_time.isoformat()
 
@@ -75,7 +79,13 @@ class LogRecordsMetricsQueryRequest:
                 filters_item: dict[str, Any]
                 if isinstance(
                     filters_item_data,
-                    (LogRecordsIDFilter, LogRecordsDateFilter, LogRecordsNumberFilter, LogRecordsBooleanFilter),
+                    (
+                        LogRecordsIDFilter,
+                        LogRecordsDateFilter,
+                        LogRecordsNumberFilter,
+                        LogRecordsBooleanFilter,
+                        LogRecordsTextFilter,
+                    ),
                 ):
                     filters_item = filters_item_data.to_dict()
                 else:
@@ -115,6 +125,7 @@ class LogRecordsMetricsQueryRequest:
     @classmethod
     def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
         from ..models.log_records_boolean_filter import LogRecordsBooleanFilter
+        from ..models.log_records_collection_filter import LogRecordsCollectionFilter
         from ..models.log_records_date_filter import LogRecordsDateFilter
         from ..models.log_records_id_filter import LogRecordsIDFilter
         from ..models.log_records_number_filter import LogRecordsNumberFilter
@@ -142,6 +153,7 @@ class LogRecordsMetricsQueryRequest:
                 data: object,
             ) -> Union[
                 "LogRecordsBooleanFilter",
+                "LogRecordsCollectionFilter",
                 "LogRecordsDateFilter",
                 "LogRecordsIDFilter",
                 "LogRecordsNumberFilter",
@@ -173,11 +185,18 @@ class LogRecordsMetricsQueryRequest:
                         raise TypeError()
                     return LogRecordsBooleanFilter.from_dict(data)
 
+                except:  # noqa: E722
+                    pass
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    return LogRecordsTextFilter.from_dict(data)
+
                 except:  # noqa: E722
                     pass
                 if not isinstance(data, dict):
                     raise TypeError()
-                return LogRecordsTextFilter.from_dict(data)
+                return LogRecordsCollectionFilter.from_dict(data)
 
             filters_item = _parse_filters_item(filters_item_data)
 
