@@ -10,6 +10,7 @@ if TYPE_CHECKING:
     from ..models.and_node import AndNode
     from ..models.filter_leaf import FilterLeaf
     from ..models.log_records_boolean_filter import LogRecordsBooleanFilter
+    from ..models.log_records_collection_filter import LogRecordsCollectionFilter
     from ..models.log_records_date_filter import LogRecordsDateFilter
     from ..models.log_records_id_filter import LogRecordsIDFilter
     from ..models.log_records_number_filter import LogRecordsNumberFilter
@@ -25,14 +26,16 @@ T = TypeVar("T", bound="LogRecordsQueryRequest")
 @_attrs_define
 class LogRecordsQueryRequest:
     """
-    Attributes:
+    Attributes
+    ----------
         experiment_id (Union[None, Unset, str]): Experiment id associated with the traces.
         filter_tree (Union['AndNode', 'FilterLeaf', 'NotNode', 'OrNode', None, Unset]):
-        filters (Union[Unset, list[Union['LogRecordsBooleanFilter', 'LogRecordsDateFilter', 'LogRecordsIDFilter',
-            'LogRecordsNumberFilter', 'LogRecordsTextFilter']]]):
+        filters (Union[Unset, list[Union['LogRecordsBooleanFilter', 'LogRecordsCollectionFilter',
+            'LogRecordsDateFilter', 'LogRecordsIDFilter', 'LogRecordsNumberFilter', 'LogRecordsTextFilter']]]):
         limit (Union[Unset, int]):  Default: 100.
         log_stream_id (Union[None, Unset, str]): Log stream id associated with the traces.
         metrics_testing_id (Union[None, Unset, str]): Metrics testing id associated with the traces.
+        previous_last_row_id (Union[None, Unset, str]):
         sort (Union[Unset, LogRecordsSortClause]):
         starting_token (Union[Unset, int]):  Default: 0.
         truncate_fields (Union[Unset, bool]):  Default: False.
@@ -45,6 +48,7 @@ class LogRecordsQueryRequest:
         list[
             Union[
                 "LogRecordsBooleanFilter",
+                "LogRecordsCollectionFilter",
                 "LogRecordsDateFilter",
                 "LogRecordsIDFilter",
                 "LogRecordsNumberFilter",
@@ -55,6 +59,7 @@ class LogRecordsQueryRequest:
     limit: Union[Unset, int] = 100
     log_stream_id: Union[None, Unset, str] = UNSET
     metrics_testing_id: Union[None, Unset, str] = UNSET
+    previous_last_row_id: Union[None, Unset, str] = UNSET
     sort: Union[Unset, "LogRecordsSortClause"] = UNSET
     starting_token: Union[Unset, int] = 0
     truncate_fields: Union[Unset, bool] = False
@@ -67,6 +72,7 @@ class LogRecordsQueryRequest:
         from ..models.log_records_date_filter import LogRecordsDateFilter
         from ..models.log_records_id_filter import LogRecordsIDFilter
         from ..models.log_records_number_filter import LogRecordsNumberFilter
+        from ..models.log_records_text_filter import LogRecordsTextFilter
         from ..models.not_node import NotNode
         from ..models.or_node import OrNode
 
@@ -88,7 +94,13 @@ class LogRecordsQueryRequest:
                 filters_item: dict[str, Any]
                 if isinstance(
                     filters_item_data,
-                    (LogRecordsIDFilter, LogRecordsDateFilter, LogRecordsNumberFilter, LogRecordsBooleanFilter),
+                    (
+                        LogRecordsIDFilter,
+                        LogRecordsDateFilter,
+                        LogRecordsNumberFilter,
+                        LogRecordsBooleanFilter,
+                        LogRecordsTextFilter,
+                    ),
                 ):
                     filters_item = filters_item_data.to_dict()
                 else:
@@ -104,6 +116,9 @@ class LogRecordsQueryRequest:
         metrics_testing_id: Union[None, Unset, str]
         metrics_testing_id = UNSET if isinstance(self.metrics_testing_id, Unset) else self.metrics_testing_id
 
+        previous_last_row_id: Union[None, Unset, str]
+        previous_last_row_id = UNSET if isinstance(self.previous_last_row_id, Unset) else self.previous_last_row_id
+
         sort: Union[Unset, dict[str, Any]] = UNSET
         if not isinstance(self.sort, Unset):
             sort = self.sort.to_dict()
@@ -127,6 +142,8 @@ class LogRecordsQueryRequest:
             field_dict["log_stream_id"] = log_stream_id
         if metrics_testing_id is not UNSET:
             field_dict["metrics_testing_id"] = metrics_testing_id
+        if previous_last_row_id is not UNSET:
+            field_dict["previous_last_row_id"] = previous_last_row_id
         if sort is not UNSET:
             field_dict["sort"] = sort
         if starting_token is not UNSET:
@@ -141,6 +158,7 @@ class LogRecordsQueryRequest:
         from ..models.and_node import AndNode
         from ..models.filter_leaf import FilterLeaf
         from ..models.log_records_boolean_filter import LogRecordsBooleanFilter
+        from ..models.log_records_collection_filter import LogRecordsCollectionFilter
         from ..models.log_records_date_filter import LogRecordsDateFilter
         from ..models.log_records_id_filter import LogRecordsIDFilter
         from ..models.log_records_number_filter import LogRecordsNumberFilter
@@ -205,6 +223,7 @@ class LogRecordsQueryRequest:
                 data: object,
             ) -> Union[
                 "LogRecordsBooleanFilter",
+                "LogRecordsCollectionFilter",
                 "LogRecordsDateFilter",
                 "LogRecordsIDFilter",
                 "LogRecordsNumberFilter",
@@ -236,11 +255,18 @@ class LogRecordsQueryRequest:
                         raise TypeError()
                     return LogRecordsBooleanFilter.from_dict(data)
 
+                except:  # noqa: E722
+                    pass
+                try:
+                    if not isinstance(data, dict):
+                        raise TypeError()
+                    return LogRecordsTextFilter.from_dict(data)
+
                 except:  # noqa: E722
                     pass
                 if not isinstance(data, dict):
                     raise TypeError()
-                return LogRecordsTextFilter.from_dict(data)
+                return LogRecordsCollectionFilter.from_dict(data)
 
             filters_item = _parse_filters_item(filters_item_data)
 
@@ -266,6 +292,15 @@ class LogRecordsQueryRequest:
 
         metrics_testing_id = _parse_metrics_testing_id(d.pop("metrics_testing_id", UNSET))
 
+        def _parse_previous_last_row_id(data: object) -> Union[None, Unset, str]:
+            if data is None:
+                return data
+            if isinstance(data, Unset):
+                return data
+            return cast(Union[None, Unset, str], data)
+
+        previous_last_row_id = _parse_previous_last_row_id(d.pop("previous_last_row_id", UNSET))
+
         _sort = d.pop("sort", UNSET)
         sort: Union[Unset, LogRecordsSortClause]
         sort = UNSET if isinstance(_sort, Unset) else LogRecordsSortClause.from_dict(_sort)
@@ -281,6 +316,7 @@ class LogRecordsQueryRequest:
             limit=limit,
             log_stream_id=log_stream_id,
             metrics_testing_id=metrics_testing_id,
+            previous_last_row_id=previous_last_row_id,
             sort=sort,
             starting_token=starting_token,
             truncate_fields=truncate_fields,
