@@ -10,7 +10,8 @@ T = TypeVar("T", bound="OpenAIFunction")
 @_attrs_define
 class OpenAIFunction:
     """
-    Attributes:
+    Attributes
+    ----------
         name (str):
     """
 
