@@ -10,7 +10,8 @@ T = TypeVar("T", bound="ProjectDeleteResponse")
 @_attrs_define
 class ProjectDeleteResponse:
     """
-    Attributes:
+    Attributes
+    ----------
         message (str):
     """
 
